@@ -73,6 +73,7 @@ class WebHandler(object):
         self.template_lookup = None
         self._file_change_watcher = None
         self._static_dir = ''
+        self.json_encoder = json.dumps
 
         cherrypy.config.update({'environment': 'embedded'})
 
@@ -92,7 +93,7 @@ class WebHandler(object):
 
     def _encode_result(self, result):
         if type(result) in (set, list, dict):
-            return json.dumps(result)
+            return self.json_encoder(result)
         else:
             return escape(str(result))
 
